"""
Pinterest Client
"""
from pinterest.generated.client.configuration import Configuration
from pinterest.generated.client.api_client import ApiClient
from pinterest.client.config import PINTEREST_ACCESS_TOKEN
from pinterest.client.config import PINTEREST_REFRESH_ACCESS_TOKEN
from pinterest.client.config import PINTEREST_APP_ID
from pinterest.client.config import PINTEREST_APP_SECRET
from pinterest.client.config import PINTEREST_API_URI
from pinterest.client.config import PINTEREST_DEBUG
from pinterest.client.config import PINTEREST_LOG_FILE
from pinterest.client.config import PINTEREST_LOGGER_FORMAT
from pinterest.client.config import PINTEREST_USER_AGENT
from pinterest.utils.refresh_access_token import get_new_access_token
from pinterest.utils.sdk_exceptions import SdkException

__all__ = ['default_sdk_client', 'PinterestSDKClient']


class PinterestSDKClient(ApiClient):
    # pylint: disable=too-many-arguments
    """
    Wrapper API client for SDK high level models

    NOTE: This class is base in a generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech
    """

    def __init__(self, configuration=None, header_name=None, header_value=None, cookie=None, pool_threads=1):
        super().__init__(configuration, header_name, header_value, cookie, pool_threads, PINTEREST_USER_AGENT)


if not PINTEREST_ACCESS_TOKEN and not PINTEREST_REFRESH_ACCESS_TOKEN:
    raise SdkException(reason="Environment variables not present. " +
        "Kindly initialize required variables: [PINTEREST_ACCESS_TOKEN] or " +
        "[PINTEREST_APP_ID, PINTEREST_APP_SECRET, PINTEREST_REFRESH_ACCESS_TOKEN]")

if not PINTEREST_ACCESS_TOKEN:
    PINTEREST_ACCESS_TOKEN = get_new_access_token(
        app_id=PINTEREST_APP_ID,
        app_secret=PINTEREST_APP_SECRET,
        refresh_access_token=PINTEREST_REFRESH_ACCESS_TOKEN,
        host=PINTEREST_API_URI,
    )

config = Configuration(
    access_token=PINTEREST_ACCESS_TOKEN,
    host=PINTEREST_API_URI,
)

config.debug = PINTEREST_DEBUG
config.logger_file = PINTEREST_LOG_FILE
config.logger_format = PINTEREST_LOGGER_FORMAT

default_sdk_client = PinterestSDKClient(configuration=config)
